@@ -8,7 +8,7 @@
 /*                           Interdisciplinary Graduate School of    */
 /*                           Science and Engineering                 */
 /*                                                                   */
-/*                1996-2013  Nagoya Institute of Technology          */
+/*                1996-2017  Nagoya Institute of Technology          */
 /*                           Department of Computer Science          */
 /*                                                                   */
 /* All rights reserved.                                              */
@@ -67,7 +67,8 @@
 *                                                                            *
 *****************************************************************************/
 
-static char *rcs_id = "$Id: dawrite.c,v 1.32 2013/12/16 09:01:54 mataki Exp $";
+static char *rcs_id =
+    "$Id$";
 
 
 /* Standard C Libraries */
@@ -75,22 +76,22 @@ static char *rcs_id = "$Id: dawrite.c,v 1.32 2013/12/16 09:01:54 mataki Exp $";
 #include <stdlib.h>
 
 #ifdef HAVE_STRING_H
-#  include <string.h>
+#include <string.h>
 #else
-#  include <strings.h>
-#  ifndef HAVE_STRRCHR
-#     define strrchr rindex
-#  endif
+#include <strings.h>
+#ifndef HAVE_STRRCHR
+#define strrchr rindex
+#endif
 #endif
 
 #ifndef WIN32
-#  include <unistd.h>
-#  include <SPTK.h>
-#  include "da.h"
+#include <unistd.h>
+#include <SPTK.h>
+#include "da.h"
 #else
-#  include "SPTK.h"
-#  include "da.h"
-#  include "winplay.h"
+#include "SPTK.h"
+#include "da.h"
+#include "winplay.h"
 #endif
 
 /* Default Value */
