@@ -8,7 +8,7 @@
 /*                           Interdisciplinary Graduate School of    */
 /*                           Science and Engineering                 */
 /*                                                                   */
-/*                1996-2014  Nagoya Institute of Technology          */
+/*                1996-2017  Nagoya Institute of Technology          */
 /*                           Department of Computer Science          */
 /*                                                                   */
 /* All rights reserved.                                              */
@@ -77,7 +77,7 @@
 *                                                                       *
 ************************************************************************/
 
-static char *rcs_id = "$Id: lsp2sp.c,v 1.6 2014/12/11 08:30:40 uratec Exp $";
+static char *rcs_id = "$Id$";
 
 
 /*  Standard C Libraries  */
@@ -85,21 +85,21 @@ static char *rcs_id = "$Id: lsp2sp.c,v 1.6 2014/12/11 08:30:40 uratec Exp $";
 #include <stdlib.h>
 
 #ifdef HAVE_STRING_H
-#  include <string.h>
+#include <string.h>
 #else
-#  include <strings.h>
-#  ifndef HAVE_STRRCHR
-#     define strrchr rindex
-#  endif
+#include <strings.h>
+#ifndef HAVE_STRRCHR
+#define strrchr rindex
+#endif
 #endif
 
 #include <ctype.h>
 #include <math.h>
 
 #if defined(WIN32)
-#  include "SPTK.h"
+#include "SPTK.h"
 #else
-#  include <SPTK.h>
+#include <SPTK.h>
 #endif
 
 /*  Default Values  */
@@ -242,7 +242,11 @@ int main(int argc, char **argv)
             lsp[i] = lsp[i] / sampling * PI2;
       }
 
-      if (loggain == 0)
+      if (itype == 3)
+         for (i = gain; i < m + gain; i++)
+            lsp[i] /= 1000;
+
+      if (gain == 1 && loggain == 0)
          *lsp = log(*lsp);
 
       lsp2sp(lsp, m, x, no, gain);
