@@ -8,7 +8,7 @@
 /*                           Interdisciplinary Graduate School of    */
 /*                           Science and Engineering                 */
 /*                                                                   */
-/*                1996-2014  Nagoya Institute of Technology          */
+/*                1996-2017  Nagoya Institute of Technology          */
 /*                           Department of Computer Science          */
 /*                                                                   */
 /* All rights reserved.                                              */
@@ -72,7 +72,7 @@
 *                                                                                       *
 ****************************************************************************************/
 
-static char *rcs_id = "$Id: mlpg.c,v 1.36 2014/12/11 08:30:42 uratec Exp $";
+static char *rcs_id = "$Id$";
 
 
 /* Standard C Libraries */
@@ -80,20 +80,20 @@ static char *rcs_id = "$Id: mlpg.c,v 1.36 2014/12/11 08:30:42 uratec Exp $";
 #include <stdlib.h>
 
 #ifdef HAVE_STRING_H
-#  include <string.h>
+#include <string.h>
 #else
-#  include <strings.h>
-#  ifndef HAVE_STRRCHR
-#     define strrchr rindex
-#  endif
+#include <strings.h>
+#ifndef HAVE_STRRCHR
+#define strrchr rindex
+#endif
 #endif
 
 #include <ctype.h>
 
 #if defined(WIN32)
-#  include "SPTK.h"
+#include "SPTK.h"
 #else
-#  include <SPTK.h>
+#include <SPTK.h>
 #endif
 
 /* default values */
@@ -583,11 +583,10 @@ double *mlpg(PStream * pst)
    void calc_k(PStream *, int);
    void update_P(PStream *);
    void update_c(PStream *, int);
-   int tcur, tmin, tmax;
+   int tmin, tmax;
    int d, m, u;
 
    pst->sm.t++;
-   tcur = pst->sm.t & pst->sm.mask;
    tmin = (pst->sm.t - pst->range) & pst->sm.mask;
    tmax = (pst->sm.t + pst->dw.maxw[WRIGHT]) & pst->sm.mask;
 
