@@ -8,7 +8,7 @@
 /*                           Interdisciplinary Graduate School of    */
 /*                           Science and Engineering                 */
 /*                                                                   */
-/*                1996-2014  Nagoya Institute of Technology          */
+/*                1996-2017  Nagoya Institute of Technology          */
 /*                           Department of Computer Science          */
 /*                                                                   */
 /* All rights reserved.                                              */
@@ -83,7 +83,7 @@
 ************************************************************************/
 
 static char *rcs_id =
-    "$Id: mlsacheck.c,v 1.18 2014/12/11 08:30:42 uratec Exp $";
+    "$Id$";
 
 
 /*  Standard C Libraries  */
@@ -91,21 +91,21 @@ static char *rcs_id =
 #include <stdlib.h>
 
 #ifdef HAVE_STRING_H
-#  include <string.h>
+#include <string.h>
 #else
-#  include <strings.h>
-#  ifndef HAVE_STRRCHR
-#     define strrchr rindex
-#  endif
+#include <strings.h>
+#ifndef HAVE_STRRCHR
+#define strrchr rindex
+#endif
 #endif
 
 #include <ctype.h>
 #include <math.h>
 
 #if defined(WIN32)
-#  include "SPTK.h"
+#include "SPTK.h"
 #else
-#  include <SPTK.h>
+#include <SPTK.h>
 #endif
 
 /*  Default Values  */
@@ -184,8 +184,8 @@ void usage(int status)
    exit(status);
 }
 
-void mlsacheck(double *mcep, int m, int fftlen, int frame,
-               double a, double r, int c)
+double mlsacheck(double *in, double *out, int m, int fftlen,
+                 double a, double r, int c)
 {
    int i;
    double gain, *x, *y, *mag = NULL, max = 0.0;
@@ -198,7 +198,7 @@ void mlsacheck(double *mcep, int m, int fftlen, int frame,
 
    /* calculate gain factor */
    for (i = 0, gain = 0.0; i <= m; i++) {
-      x[i] = mcep[i];
+      x[i] = in[i];
       gain += x[i] * pow(-a, i);
    }
 
@@ -206,7 +206,7 @@ void mlsacheck(double *mcep, int m, int fftlen, int frame,
    x[0] -= gain;
 
    /* check stability */
-   if (c == 0 || c == 2 || c == 3) {    /* usual mode */
+   if (c != 1 && c != 4) {      /* usual mode */
       mag = dgetmem(fftlen);
       fillz(mag, sizeof(*mag), fftlen);
       fftr(x, y, fftlen);
@@ -220,14 +220,10 @@ void mlsacheck(double *mcep, int m, int fftlen, int frame,
          max += x[i];
    }
 
-   /* modification MLSA filter coefficients */
-   if (max > r) {
-      /* output ascii report */
-      fprintf(stderr,
-              "[No. %d] is unstable frame (maximum = %f, threshold = %f)\n",
-              frame, max, r);
-
-      /* modification */
+   /* modify MLSA filter coefficients */
+   if (c == 0 || c == 1 || max <= r) {
+      memcpy(out, in, sizeof(*out) * (m + 1));
+   } else {
       if (c == 2) {             /* clipping */
          for (i = 0; i < fftlen; i++) {
             if (mag[i] > r) {
@@ -235,38 +231,39 @@ void mlsacheck(double *mcep, int m, int fftlen, int frame,
                y[i] *= r / mag[i];
             }
          }
+         ifft(x, y, fftlen);
+         x[0] += gain;
+         memcpy(out, x, sizeof(*out) * (m + 1));
       } else if (c == 3) {      /* scaling */
          for (i = 0; i < fftlen; i++) {
             x[i] *= r / max;
             y[i] *= r / max;
          }
+         ifft(x, y, fftlen);
+         x[0] += gain;
+         memcpy(out, x, sizeof(*out) * (m + 1));
       } else if (c == 4) {      /* fast mode */
          for (i = 0; i <= m; i++)
             x[i] *= r / max;
+         x[0] += gain;
+         memcpy(out, x, sizeof(*out) * (m + 1));
       }
    }
 
-   /* output MLSA filter coefficients */
-   if (c == 0 || c == 1 || max <= r) {  /* no modification */
-      fwritef(mcep, sizeof(*mcep), m + 1, stdout);
-   } else {
-      if (c == 2 || c == 3)
-         ifft(x, y, fftlen);
-      x[0] += gain;
-      fwritef(x, sizeof(*x), m + 1, stdout);
-   }
-
    free(x);
    free(y);
-   if (c == 0 || c == 2 || c == 3)
+   if (c != 1 && c != 4) {
       free(mag);
+   }
+
+   return max;
 }
 
 int main(int argc, char **argv)
 {
    int m = ORDER, pd = PADEORDER, fftlen = FFTLENGTH, stable_condition =
        STABLE1, frame = 0, c = 0;
-   double *mcep, a = ALPHA, r = PADE4_THRESH1, R = 0.0;
+   double *in, *out, max, a = ALPHA, r = PADE4_THRESH1, R = 0.0;
    FILE *fp = stdin;
 
    if ((cmnd = strrchr(argv[0], '/')) == NULL) {
@@ -356,11 +353,21 @@ int main(int argc, char **argv)
    if (R != 0.0)
       r = R;
 
-   mcep = dgetmem(m + 1);
+   in = dgetmem(m + 1);
+   out = dgetmem(m + 1);
 
    /* check stability of MLSA filter and output */
-   while (freadf(mcep, sizeof(*mcep), m + 1, fp) == m + 1) {
-      mlsacheck(mcep, m, fftlen, frame, a, r, c);
+   while (freadf(in, sizeof(*in), m + 1, fp) == m + 1) {
+      max = mlsacheck(in, out, m, fftlen, a, r, c);
+
+      /* output ascii report */
+      if (max > r) {
+         fprintf(stderr,
+                 "[No. %d] is unstable frame (maximum = %f, threshold = %f)\n",
+                 frame, max, r);
+      }
+
+      fwritef(out, sizeof(*out), m + 1, stdout);
       frame++;
    }
 
