@@ -25,7 +25,7 @@
 /*                           Interdisciplinary Graduate School of    */
 /*                           Science and Engineering                 */
 /*                                                                   */
-/*                1996-2014  Nagoya Institute of Technology          */
+/*                1996-2017  Nagoya Institute of Technology          */
 /*                           Department of Computer Science          */
 /*                                                                   */
 /* All rights reserved.                                              */
@@ -61,7 +61,7 @@
 
 /****************************************************************
 
-    $Id: sigproc.c,v 1.6 2014/12/11 08:30:43 uratec Exp $
+    $Id$
 
 ****************************************************************/
 
@@ -551,7 +551,6 @@ void crossf(data, size, start, nlags, engref, maxloc, maxval, correl)
   register  float *dq, t, *p, engr, *dds, amax;
   register  double engc;
   int i, iloc, total;
-  int sizei, sizeo, maxsize;
 
   /* Compute mean in reference window and subtract this from the
      entire sequence.  This doesn't do too much damage to the data
@@ -584,10 +583,6 @@ void crossf(data, size, start, nlags, engref, maxloc, maxval, correl)
   engr /= size;
   for(j=size+nlags+start, dq = dbdata, p=data; j--; )  *dq++ = *p++ - engr;
 
-  maxsize = start + nlags;
-  sizei = size + start + nlags + 1;
-  sizeo = nlags + 1;
- 
   /* Compute energy in reference window. */
   for(j=size, dp=dbdata, sum=0.0; j--; ) {
     st = *dp++;
