@@ -8,7 +8,7 @@
 /*                           Interdisciplinary Graduate School of    */
 /*                           Science and Engineering                 */
 /*                                                                   */
-/*                1996-2014  Nagoya Institute of Technology          */
+/*                1996-2017  Nagoya Institute of Technology          */
 /*                           Department of Computer Science          */
 /*                                                                   */
 /* All rights reserved.                                              */
@@ -88,19 +88,19 @@
 *                                                                       *
 ************************************************************************/
 
-static char *rcs_id = "$Id: vstat.c,v 1.37 2014/12/11 08:30:51 uratec Exp $";
+static char *rcs_id = "$Id$";
 
 
 /*  Standard C Libralies  */
 #include <stdio.h>
 
 #ifdef HAVE_STRING_H
-#  include <string.h>
+#include <string.h>
 #else
-#  include <strings.h>
-#  ifndef HAVE_STRRCHR
-#     define strrchr rindex
-#  endif
+#include <strings.h>
+#ifndef HAVE_STRRCHR
+#define strrchr rindex
+#endif
 #endif
 
 #include <stdlib.h>
@@ -108,9 +108,9 @@ static char *rcs_id = "$Id: vstat.c,v 1.37 2014/12/11 08:30:51 uratec Exp $";
 #include <math.h>
 
 #if defined(WIN32)
-#  include "SPTK.h"
+#include "SPTK.h"
 #else
-#  include <SPTK.h>
+#include <SPTK.h>
 #endif
 
 /*  Default Values  */
@@ -268,8 +268,8 @@ double t_percent(const double p, const int df)
 void quicksort(double *x, int left, int right)
 {
    int i, j;
-   int pivot;
-   int tmp;
+   double pivot;
+   double tmp;
 
    i = left;
    j = right;
